@@ -2,7 +2,7 @@ package App::Hachero;
 use strict;
 use warnings;
 use 5.00800;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 use Class::Component;
 use base qw(Class::Accessor::Fast);
 use UNIVERSAL::require;
@@ -10,7 +10,13 @@ use File::Spec;
 use Module::Collect;
 
 __PACKAGE__->load_components(qw/DisableDynamicPlugin Plaggerize Autocall::InjectMethod/);
-__PACKAGE__->mk_accessors(qw/currentline currentlog currentinfo result work_path/);
+__PACKAGE__->mk_accessors(qw/
+    currentline 
+    currentlog 
+    currentinfo 
+    result 
+    work_path 
+    /);
 
 my $packages_from_plugin_path;
 my $context;
@@ -22,6 +28,7 @@ sub new {
     my $self = $class->SUPER::new($args);
     $self->result({});
     $context = $self;
+    $self->initialize;
     $self;
 }
 
@@ -62,7 +69,6 @@ sub run_hook_and_check {
 sub run {
     my $self = shift;
     $self->log(debug => sprintf ('run start: %s', scalar localtime));
-    $self->initialize;
     $self->run_hook('fetch');
     while( $self->set_currentline ){
         $self->run_hook_and_check('parse') or next;
@@ -91,13 +97,16 @@ sub initialize {
     if( !-d $work_path ){
         mkdir $work_path;
     }
+    $self->run_hook('initialize');
 }
 
 sub class_component_load_plugin_resolver {
     my ($self, $package) = @_;
-    $package = "App::Hachero::Plugin::$package";
+    if ( $package !~ m{App::Hachero::Plugin::} ) {
+        $package = "App::Hachero::Plugin::$package";
+    }
     for my $pkg (@{ $packages_from_plugin_path }) {
-        return $pkg if $pkg->{package} eq $package;
+        return $pkg if $pkg->package eq $package;
     }
     return undef;
 }
@@ -107,8 +116,6 @@ __END__
 
 =pod
 
-=encoding utf-8
-
 =head1 NAME
 
 App::Hachero - a plaggable log analyzing framework
@@ -123,7 +130,7 @@ Hachero is plaggable log analyzing framework. You can make your own plugin to an
 
 =head2 configuration
 
-You can work_path and plugin_path configuration in the global section. Put your plugin in the plugin_path.
+You can set work_path and plugin_path configuration in the global section. Put your plugin in the plugin_path.
 
   ---
   global:
