@@ -13,7 +13,7 @@ sub output : Hook {
     }
     for my $key (keys %{$context->result}) {
         (my $table = $key) =~ s/\:\://g;
-        my $rs = eval {$schema->resultset($table)};
+        my $rs = eval {$schema->resultset(ucfirst $table)};
         if ($@) {
             $context->log(error => $!);
             next;
@@ -45,8 +45,6 @@ __END__
 
 =pod
 
-=encoding utf8
-
 =head1 NAME
 
 App::Hachero::Plugin::Output::DBIC - writes results to databases via DBIx::Class
